@@ -6,10 +6,11 @@
 #' @inheritParams interval
 #' @param output Output format. It can be either the number of records
 #' ("record") that are in observation in the specific interval of time, the
-#' number of person-days ("person-days"), the number of subjects ("person").
+#' number of person-days ("person-days"), the number of subjects ("person"),
+#' the number of females ("sex") or the median age of population in observation ("age").
 #' @param ageGroup A list of age groups to stratify results by.
 #' @param sex Boolean variable. Whether to stratify by sex (TRUE) or not
-#' (FALSE).
+#' (FALSE). For output = "sex" this stratification is not applied.
 #' @inheritParams dateRange-startDate
 #' @return A summarised_result object.
 #' @export
@@ -22,8 +23,8 @@
 #' result <- summariseInObservation(
 #'   cdm$observation_period,
 #'   interval = "months",
-#'   output = c("person-days","record"),
-#'   ageGroup = list("<=60" = c(0,60), ">60" = c(61, Inf)),
+#'   output = c("person-days", "record"),
+#'   ageGroup = list("<=60" = c(0, 60), ">60" = c(61, Inf)),
 #'   sex = TRUE
 #' )
 #'
@@ -49,7 +50,7 @@ summariseInObservation <- function(observationPeriod,
     return(omopgenerics::emptySummarisedResult(settings = createSettings(result_type = "summarise_in_observation")))
   }
 
-  omopgenerics::assertChoice(output, choices = c("person-days","record", "person"), call = parent.frame())
+  omopgenerics::assertChoice(output, choices = c("person-days", "record", "person", "age", "sex"), call = parent.frame())
   ageGroup <- omopgenerics::validateAgeGroupArgument(ageGroup, ageGroupName = "")[[1]]
   omopgenerics::assertLogical(sex, length = 1)
   original_interval <- interval
@@ -83,46 +84,60 @@ summariseInObservation <- function(observationPeriod,
     cdm <- cdm |>
       omopgenerics::insertTable(name = paste0(tablePrefix, "interval"), table = timeInterval)
   }
-
+  result <- list()
   # Count records ----
-  result <- observationPeriod |>
-    countRecords(cdm, start_date_name, end_date_name, interval, output, tablePrefix)
+  if (any(output %in% c("person-days", "sex", "record", "person"))) {
+    # Calculate denominator ----
 
-  # Add category sex overall
-  result <- addSexOverall(result, sex)
+    denominator <- cdm |> getDenominator(output)
+    result$count <- observationPeriod |>
+      countRecords(cdm, start_date_name, end_date_name, interval, output, tablePrefix)
 
-  # Create summarisedResult
-  result <- createSummarisedResultObservationPeriod(result, observationPeriod, name, denominator, dateRange, original_interval)
+    # Add category sex overall
+    result$count <- addSexOverall(result$count, sex)
+
+    # Create summarisedResult
+    result$count <- createSummarisedResultObservationPeriod(result$count, observationPeriod, sex, name, denominator, dateRange, original_interval)
+  }
+  if ("age" %in% output) {
+    result$age <- createSummarisedResultAge(observationPeriod, cdm, start_date_name, end_date_name, interval, tablePrefix, sex)
+  }
+  result <- result |> dplyr::bind_rows()
+  result <- result |>
+    omopgenerics::newSummarisedResult(settings = createSettings(result_type = "summarise_in_observation", study_period = dateRange) |>
+      dplyr::mutate("interval" = .env$original_interval))
 
   CDMConnector::dropSourceTable(cdm, name = dplyr::starts_with(tablePrefix))
   return(result)
 }
 
 
-getDenominator <- function(cdm, output){
-  if("record" %in% output){
+getDenominator <- function(cdm, output) {
+  if ("record" %in% output) {
     denominator_record <- tibble::tibble(
       "denominator" = c(cdm[["person"]] |>
-                          dplyr::ungroup() |>
-                          dplyr::select("person_id") |>
-                          dplyr::summarise("n" = dplyr::n()) |>
-                          dplyr::pull("n")),
-      "variable_name" = "Number records in observation")
+        dplyr::ungroup() |>
+        dplyr::select("person_id") |>
+        dplyr::summarise("n" = dplyr::n()) |>
+        dplyr::pull("n")),
+      "variable_name" = "Number records in observation"
+    )
   } else {
     denominator_record <- tibble::tibble()
   }
-  if("person" %in% output){
+  if ("person" %in% output) {
     denominator_person <- tibble::tibble(
       "denominator" = c(cdm[["person"]] |>
-                          dplyr::ungroup() |>
-                          dplyr::select("person_id") |>
-                          dplyr::summarise("n" = dplyr::n()) |>
-                          dplyr::pull("n")),
-      "variable_name" = "Number subjects in observation")
+        dplyr::ungroup() |>
+        dplyr::select("person_id") |>
+        dplyr::summarise("n" = dplyr::n()) |>
+        dplyr::pull("n")),
+      "variable_name" = "Number subjects in observation"
+    )
   } else {
     denominator_person <- tibble::tibble()
   }
-  if("person-days" %in% output){
+  if ("person-days" %in% output) {
     y <- cdm[["observation_period"]] |>
       dplyr::ungroup() |>
       dplyr::inner_join(cdm[["person"]] |> dplyr::select("person_id"), by = "person_id") %>%
@@ -132,13 +147,26 @@ getDenominator <- function(cdm, output){
 
     denominator_pd <- tibble::tibble(
       "denominator" = y,
-      "variable_name" = "Number person-days")
-    
+      "variable_name" = "Number person-days"
+    )
   } else {
     denominator_pd <- tibble::tibble()
   }
+  if ("sex" %in% output) {
+    denominator_sex <- tibble::tibble(
+      "denominator" = c(cdm[["person"]] |>
+        dplyr::ungroup() |>
+        dplyr::filter(.data$gender_concept_id %in% c(8507, 8532)) |>
+        dplyr::select("person_id") |>
+        dplyr::summarise("n" = dplyr::n()) |>
+        dplyr::pull("n")),
+      "variable_name" = "Number females in observation"
+    )
+  } else {
+    denominator_sex <- tibble::tibble()
+  }
 
-  denominator <- rbind(denominator_record, denominator_person, denominator_pd)
+  denominator <- rbind(denominator_record, denominator_person, denominator_pd, denominator_sex)
   return(denominator)
 }
 
@@ -178,11 +206,9 @@ getIntervalTibbleForObservation <- function(omopTable, start_date_name, end_date
 }
 
 
-countRecords <- function(observationPeriod, cdm, start_date_name, end_date_name, interval, output, tablePrefix){
-
-  if("person-days" %in% output){
-    if(interval != "overall"){
-      
+countRecords <- function(observationPeriod, cdm, start_date_name, end_date_name, interval, output, tablePrefix) {
+  if ("person-days" %in% output) {
+    if (interval != "overall") {
       x <- cdm[[paste0(tablePrefix, "interval")]] |>
         dplyr::cross_join(
           observationPeriod |>
@@ -217,10 +243,8 @@ countRecords <- function(observationPeriod, cdm, start_date_name, end_date_name,
     personDays <- createEmptyIntervalTable(interval)
   }
 
-  if("record" %in% output){
-
-    if(interval != "overall"){
-
+  if ("record" %in% output) {
+    if (interval != "overall") {
       x <- observationPeriod |>
         dplyr::mutate("start_date" = as.Date(paste0(as.character(as.integer(clock::get_year(.data[[start_date_name]]))), "-", as.character(as.integer(clock::get_month(.data[[start_date_name]]))), "-01"))) |>
         dplyr::mutate("end_date" = as.Date(paste0(as.character(as.integer(clock::get_year(.data[[end_date_name]]))), "-", as.character(as.integer(clock::get_month(.data[[end_date_name]]))), "-01"))) |>
@@ -249,12 +273,11 @@ countRecords <- function(observationPeriod, cdm, start_date_name, end_date_name,
     records <- createEmptyIntervalTable(interval)
   }
 
-  if("person" %in% output){
-
-    if(interval != "overall"){
+  if ("person" %in% output) {
+    if (interval != "overall") {
       x <- observationPeriod |>
-        dplyr::mutate("start_date" = as.Date(paste0(as.character(as.integer(clock::get_year(.data[[start_date_name]]))),"-",as.character(as.integer(clock::get_month(.data[[start_date_name]]))),"-01"))) |>
-        dplyr::mutate("end_date" = as.Date(paste0(as.character(as.integer(clock::get_year(.data[[end_date_name]]))),"-",as.character(as.integer(clock::get_month(.data[[end_date_name]]))),"-01"))) |>
+        dplyr::mutate("start_date" = as.Date(paste0(as.character(as.integer(clock::get_year(.data[[start_date_name]]))), "-", as.character(as.integer(clock::get_month(.data[[start_date_name]]))), "-01"))) |>
+        dplyr::mutate("end_date" = as.Date(paste0(as.character(as.integer(clock::get_year(.data[[end_date_name]]))), "-", as.character(as.integer(clock::get_month(.data[[end_date_name]]))), "-01"))) |>
         dplyr::group_by(.data$start_date, .data$end_date, .data$age_group, .data$sex) |>
         dplyr::summarise(estimate_value = dplyr::n_distinct("person_id"), .groups = "drop") |>
         dplyr::compute(temporary = FALSE, name = tablePrefix)
@@ -262,13 +285,13 @@ countRecords <- function(observationPeriod, cdm, start_date_name, end_date_name,
       subjects <- cdm[[paste0(tablePrefix, "interval")]] |>
         dplyr::cross_join(x) |>
         dplyr::filter((.data$start_date < .data$interval_start_date & .data$end_date >= .data$interval_start_date) |
-                        (.data$start_date >= .data$interval_start_date & .data$start_date <= .data$interval_end_date)) |>
+          (.data$start_date >= .data$interval_start_date & .data$start_date <= .data$interval_end_date)) |>
         dplyr::group_by(.data$time_interval, .data$age_group, .data$sex) |>
         dplyr::summarise(estimate_value = sum(.data$estimate_value, na.rm = TRUE), .groups = "drop") |>
         dplyr::mutate("variable_name" = "Number subjects in observation") |>
         dplyr::collect()
       additional_column <- "time_interval"
-    }else{
+    } else {
       subjects <- observationPeriod |>
         dplyr::group_by(.data$age_group, .data$sex) |>
         dplyr::summarise(estimate_value = dplyr::n_distinct("person_id"), .groups = "drop") |>
@@ -276,11 +299,46 @@ countRecords <- function(observationPeriod, cdm, start_date_name, end_date_name,
         dplyr::collect()
       additional_column <- character()
     }
-  }else{
+  } else {
     subjects <- createEmptyIntervalTable(interval)
   }
 
+  if ("sex" %in% output) {
+    if (interval != "overall") {
+      x <- observationPeriod |>
+        dplyr::mutate("start_date" = as.Date(paste0(as.character(as.integer(clock::get_year(.data[[start_date_name]]))), "-", as.character(as.integer(clock::get_month(.data[[start_date_name]]))), "-01"))) |>
+        dplyr::mutate("end_date" = as.Date(paste0(as.character(as.integer(clock::get_year(.data[[end_date_name]]))), "-", as.character(as.integer(clock::get_month(.data[[end_date_name]]))), "-01"))) |>
+        dplyr::cross_join(cdm[[paste0(tablePrefix, "interval")]]) |>
+        dplyr::filter((.data$start_date < .data$interval_start_date & .data$end_date >= .data$interval_start_date) |
+          (.data$start_date >= .data$interval_start_date & .data$start_date <= .data$interval_end_date)) |>
+        PatientProfiles::addSexQuery() |>
+        suppressWarnings() |>
+        dplyr::compute(temporary = FALSE, name = tablePrefix)
 
+      strata <- c("time_interval", "age_group")
+      additional_column <- "time_interval"
+    } else {
+      x <- observationPeriod |>
+        PatientProfiles::addSexQuery() |>
+        suppressWarnings() |>
+        dplyr::compute(temporary = FALSE, name = tablePrefix)
+      strata <- "age_group"
+      additional_column <- character()
+    }
+
+    sex <- x |>
+      dplyr::group_by(dplyr::across(dplyr::all_of(strata))) |>
+      dplyr::filter(.data$sex == "Female") |>
+      dplyr::summarise("estimate_value" = dplyr::n(), .groups = "drop") |>
+      dplyr::collect() |>
+      dplyr::bind_rows() |>
+      dplyr::mutate(
+        "variable_name" = "Number females in observation",
+        "sex" = "overall"
+      )
+  } else {
+    sex <- createEmptyIntervalTable(interval)
+  }
 
   x <- personDays |>
     dplyr::mutate(estimate_value = as.numeric(.data$estimate_value)) |>
@@ -288,19 +346,23 @@ countRecords <- function(observationPeriod, cdm, start_date_name, end_date_name,
       records |>
         dplyr::mutate(estimate_value = as.numeric(.data$estimate_value)),
       subjects |>
+        dplyr::mutate(estimate_value = as.numeric(.data$estimate_value)),
+      sex |>
         dplyr::mutate(estimate_value = as.numeric(.data$estimate_value))
     ) |>
     omopgenerics::uniteAdditional(additional_column) |>
-    dplyr::arrange(dplyr::across(dplyr::any_of("additional_level")))
+    dplyr::arrange(dplyr::across(dplyr::any_of("additional_level"))) |>
+    dplyr::mutate(
+      "estimate_name" = "count",
+      "estimate_type" = "integer"
+    )
 
   return(x)
 }
 
-createSummarisedResultObservationPeriod <- function(result, observationPeriod, name, denominator, dateRange, original_interval) {
+createSummarisedResultObservationPeriod <- function(result, observationPeriod, sex, name, denominator, dateRange, original_interval) {
   if (dim(result)[1] == 0) {
-    result <- omopgenerics::emptySummarisedResult() |>
-      omopgenerics::newSummarisedResult(settings = createSettings(result_type = "summarise_in_observation", study_period = dateRange) |>
-        dplyr::mutate("interval" = .env$original_interval))
+    result <- omopgenerics::emptySummarisedResult()
   } else {
     result <- result |>
       dplyr::mutate("estimate_value" = sprintf("%.0f", .data$estimate_value)) |>
@@ -310,9 +372,7 @@ createSummarisedResultObservationPeriod <- function(result, observationPeriod, n
         "cdm_name" = omopgenerics::cdmName(omopgenerics::cdmReference(observationPeriod)),
         "group_name" = "omop_table",
         "group_level" = name,
-        "variable_level" = as.character(NA),
-        "estimate_name" = "count",
-        "estimate_type" = "integer"
+        "variable_level" = as.character(NA)
       )
 
     result <- result |>
@@ -320,14 +380,64 @@ createSummarisedResultObservationPeriod <- function(result, observationPeriod, n
       dplyr::group_by(.data$additional_level, .data$strata_level, .data$variable_name) |>
       dplyr::mutate(estimate_type = dplyr::if_else(dplyr::row_number() == 2, "percentage", .data$estimate_type)) |>
       dplyr::inner_join(denominator, by = "variable_name") |>
-      dplyr::mutate(estimate_value = dplyr::if_else(.data$estimate_type == "percentage", as.character(as.numeric(.data$estimate_value) / denominator * 100), .data$estimate_value)) |>
+      dplyr::mutate(estimate_value = dplyr::if_else(.data$estimate_type == "percentage", sprintf("%.2f", as.numeric(.data$estimate_value) / denominator * 100), .data$estimate_value)) |>
       dplyr::select(-c("denominator")) |>
-      dplyr::mutate(estimate_name = dplyr::if_else(.data$estimate_type == "percentage", "percentage", .data$estimate_name)) |>
-      omopgenerics::newSummarisedResult(settings = createSettings(result_type = "summarise_in_observation", study_period = dateRange) |>
-        dplyr::mutate("interval" = .env$original_interval))
+      dplyr::mutate(estimate_name = dplyr::if_else(.data$estimate_type == "percentage", "percentage", .data$estimate_name))
   }
   return(result)
 }
+createSummarisedResultAge <- function(observationPeriod, cdm, start_date_name, end_date_name, interval, tablePrefix, sex) {
+  strata <- list(character(), "sex")[c(TRUE, sex)]
+  if (interval != "overall") {
+    x <- observationPeriod |>
+      dplyr::mutate("start_date" = as.Date(paste0(as.character(as.integer(clock::get_year(.data[[start_date_name]]))), "-", as.character(as.integer(clock::get_month(.data[[start_date_name]]))), "-01"))) |>
+      dplyr::mutate("end_date" = as.Date(paste0(as.character(as.integer(clock::get_year(.data[[end_date_name]]))), "-", as.character(as.integer(clock::get_month(.data[[end_date_name]]))), "-01"))) |>
+      dplyr::cross_join(cdm[[paste0(tablePrefix, "interval")]]) |>
+      dplyr::filter((.data$start_date < .data$interval_start_date & .data$end_date >= .data$interval_start_date) |
+        (.data$start_date >= .data$interval_start_date & .data$start_date <= .data$interval_end_date)) |>
+      dplyr::mutate(index_date = dplyr::if_else(
+        .data[[start_date_name]] >= .data$interval_start_date,
+        .data[[start_date_name]],
+        .data$interval_start_date
+      )) |>
+      PatientProfiles::addAgeQuery(indexDate = "index_date") |>
+      dplyr::compute(temporary = FALSE, name = tablePrefix)
+
+    additional_column <- "time_interval"
+  } else {
+    x <- observationPeriod |>
+      PatientProfiles::addAgeQuery(indexDate = start_date_name) |>
+      dplyr::compute(temporary = FALSE, name = tablePrefix)
+
+    additional_column <- character()
+  }
+
+  res <- purrr::map(strata, \(stratax) {
+    x |>
+      dplyr::group_by(dplyr::across(dplyr::all_of(c("age_group", stratax, additional_column)))) |>
+      dplyr::summarise(estimate_value = stats::median(.data$age), .groups = "drop") |>
+      dplyr::collect()
+  }) |>
+    dplyr::bind_rows() |>
+    dplyr::mutate(
+      "variable_name" = "Median age in observation",
+      "estimate_name" = "median",
+      "estimate_type" = "numeric",
+      "estimate_value" = sprintf("%.0f", as.numeric(.data$estimate_value))
+    ) |>
+    omopgenerics::uniteAdditional(additional_column) |>
+    dplyr::arrange(dplyr::across(dplyr::any_of("additional_level"))) |>
+    omopgenerics::uniteStrata(cols = c("sex"[sex], "age_group")) |>
+    dplyr::mutate(
+      "result_id" = as.integer(1),
+      "cdm_name" = omopgenerics::cdmName(omopgenerics::cdmReference(observationPeriod)),
+      "group_name" = "omop_table",
+      "group_level" = "observation_period",
+      "variable_level" = as.character(NA)
+    )
+  return(res)
+}
+
 
 addStrataToPeopleInObservation <- function(cdm, ageGroup, sex, tablePrefix, dateRange) {
   demographics <- cdm |>
@@ -392,7 +502,8 @@ addSexOverall <- function(result, sex) {
   if (sex) {
     result <- result |> rbind(
       result |>
-        dplyr::group_by(.data$age_group, .data$additional_level, .data$variable_name, .data$additional_name) |>
+        dplyr::filter(.data$sex != "overall") |>
+        dplyr::group_by(.data$age_group, .data$additional_level, .data$variable_name, .data$additional_name, .data$estimate_name, .data$estimate_type) |>
         dplyr::summarise(estimate_value = sum(.data$estimate_value, na.rm = TRUE), .groups = "drop") |>
         dplyr::mutate(sex = "overall")
     )
