@@ -1,4 +1,3 @@
-
 #' Create a visual table from a summariseObservationPeriod() result.
 #' @param result A summarised_result object.
 #' @param type Type of formatting output table, either "gt" or "flextable".
@@ -24,7 +23,8 @@ tableObservationPeriod <- function(result,
   # subset to result_type of interest
   result <- result |>
     omopgenerics::filterSettings(
-      .data$result_type == "summarise_observation_period")
+      .data$result_type == "summarise_observation_period"
+    )
 
   # check if it is empty
   if (nrow(result) == 0) {
@@ -41,21 +41,22 @@ tableObservationPeriod <- function(result,
     dplyr::filter(is.na(.data$variable_level)) |> # to remove density
     formatColumn("variable_name") |>
     # Arrange by observation period ordinal
-    dplyr::mutate(order = dplyr::coalesce(as.numeric(stringr::str_extract(.data$group_level, "\\d+")),0)) |>
+    dplyr::mutate(order = dplyr::coalesce(as.numeric(stringr::str_extract(.data$group_level, "\\d+")), 0)) |>
     dplyr::arrange(.data$order) |>
     dplyr::select(-"order") |>
     visOmopResults::visOmopTable(
       estimateName = c(
         "N" = "<count>",
         "mean (sd)" = "<mean> (<sd>)",
-        "median [Q25 - Q75]" = "<median> [<q25> - <q75>]"),
+        "median [Q25 - Q75]" = "<median> [<q25> - <q75>]"
+      ),
       header = header,
       groupColumn = omopgenerics::strataColumns(result),
       hide = c(
-        "result_id", "estimate_type", "strata_name", "variable_level"),
+        "result_id", "estimate_type", "strata_name", "variable_level"
+      ),
       type = type,
       .options = list(keepNotFormatted = FALSE) # to consider removing this? If
       # the user adds some custom estimates they are not going to be displayed in
     )
 }
-
