@@ -1,4 +1,3 @@
-
 on_github <- function() {
   !interactive() && !identical(Sys.getenv("NOT_CRAN"), "false")
 }
@@ -11,8 +10,7 @@ if (on_github()) {
   CDMConnector::downloadEunomiaData(overwrite = TRUE)
 }
 schema <- function(type = Sys.getenv("DB_TO_TEST", "duckdb")) {
-  switch(
-    type,
+  switch(type,
     "duckdb" = c(schema = "main", prefix = "omop_sketch_"),
     "postgres" = c(schema = "results", prefix = "os_")
   )
@@ -51,32 +49,32 @@ cdmEunomia <- function() {
 writeSchema <- function(dbToTest = Sys.getenv("DB_TO_TEST", "duckdb")) {
   prefix <- paste0("coco_", sample(letters, 4) |> paste0(collapse = ""), "_")
   switch(dbToTest,
-         "duckdb" = c(schema = "main", prefix = prefix),
-         "sql server" = c(catalog = "ohdsi", schema = "dbo", prefix = prefix),
-         "redshift" = c(schema = "resultsv281", prefix = prefix)
+    "duckdb" = c(schema = "main", prefix = prefix),
+    "sql server" = c(catalog = "ohdsi", schema = "dbo", prefix = prefix),
+    "redshift" = c(schema = "resultsv281", prefix = prefix)
   )
 }
 connection <- function(dbToTest = Sys.getenv("DB_TO_TEST", "duckdb")) {
   switch(dbToTest,
-         "duckdb" = DBI::dbConnect(duckdb::duckdb(), ":memory:"),
-         "sql server" = DBI::dbConnect(
-           odbc::odbc(),
-           Driver = "ODBC Driver 18 for SQL Server",
-           Server = Sys.getenv("CDM5_SQL_SERVER_SERVER"),
-           Database = Sys.getenv("CDM5_SQL_SERVER_CDM_DATABASE"),
-           UID = Sys.getenv("CDM5_SQL_SERVER_USER"),
-           PWD = Sys.getenv("CDM5_SQL_SERVER_PASSWORD"),
-           TrustServerCertificate = "yes",
-           Port = 1433
-         ),
-         "redshift" = DBI::dbConnect(
-           RPostgres::Redshift(),
-           dbname = Sys.getenv("CDM5_REDSHIFT_DBNAME"),
-           port = Sys.getenv("CDM5_REDSHIFT_PORT"),
-           host = Sys.getenv("CDM5_REDSHIFT_HOST"),
-           user = Sys.getenv("CDM5_REDSHIFT_USER"),
-           password = Sys.getenv("CDM5_REDSHIFT_PASSWORD")
-         )
+    "duckdb" = DBI::dbConnect(duckdb::duckdb(), ":memory:"),
+    "sql server" = DBI::dbConnect(
+      odbc::odbc(),
+      Driver = "ODBC Driver 18 for SQL Server",
+      Server = Sys.getenv("CDM5_SQL_SERVER_SERVER"),
+      Database = Sys.getenv("CDM5_SQL_SERVER_CDM_DATABASE"),
+      UID = Sys.getenv("CDM5_SQL_SERVER_USER"),
+      PWD = Sys.getenv("CDM5_SQL_SERVER_PASSWORD"),
+      TrustServerCertificate = "yes",
+      Port = 1433
+    ),
+    "redshift" = DBI::dbConnect(
+      RPostgres::Redshift(),
+      dbname = Sys.getenv("CDM5_REDSHIFT_DBNAME"),
+      port = Sys.getenv("CDM5_REDSHIFT_PORT"),
+      host = Sys.getenv("CDM5_REDSHIFT_HOST"),
+      user = Sys.getenv("CDM5_REDSHIFT_USER"),
+      password = Sys.getenv("CDM5_REDSHIFT_PASSWORD")
+    )
   )
 }
 copyCdm <- function(cdm) {
@@ -84,7 +82,7 @@ copyCdm <- function(cdm) {
     con = connection(), cdm = cdm, schema = writeSchema(), overwrite = TRUE
   )
 }
-checkResultType <- function(result, result_type){
+checkResultType <- function(result, result_type) {
   expect_true(
     result |>
       omopgenerics::settings() |>
